==> tecfy_basic_package-1.0.0.tar.gz: lib/services/config.service.dart <==
part of tecfy_basic_package;

class ConfigService {
  static String? apiURL;
  static String? wsURL;
  static bool isRTL = false;

  // static IConfig config;
  static IThemeConfig? theme;
  //static User user;
  // static String token;
  // static Language language = Language.arabic;
  // static bool isArabic = (language ?? Language.arabic) == Language.arabic;
  // static String languagePrefex = (language ?? Language.arabic) == Language.arabic ? 'Ar' : 'En';
  // static bool isLogin = false;
  static SharedPreferences? _prefs;

  static set token(v) {
    if (_prefs == null)
      init().then((_) => setValueString('token', v));
    else
      setValueString('token', v);
  }

  static set isLogin(v) {
    if (_prefs == null)
      init().then((_) => setValueBool('is_login', v));
    else
      setValueBool('is_login', v);
  }

  static bool get isLogin => getValueBool('is_login');
  static String get token => getValueString('token');

  static Future init() async {
    try {
      //if(Platform.isAndroid || Platform.isIOS )
      WidgetsFlutterBinding.ensureInitialized();
      if (_prefs != null) return;
      if (TecfyBasicApp.isTest)
        SharedPreferences.setMockInitialValues({'operation_mode': 1});
      print('----- start prefs');
      _prefs = await SharedPreferences.getInstance();
      print('----- prefs as added');
    } catch (err, t) {
      print('XXXXXXXXXXXXXXXXXXX Config init error XXXXXXXXXXXXXX');
      print(err);
      print(t);
    }
    print('------------Config Done!');
  }

  // static Future<bool> saveConfig()async{
  //   // if(_useFile){
  //   //     // print('--------------- write local collection ($entity)------------------');
  //   //     var file = File("${DatabaseService.pathString}config.json");
  //   //     await file.writeAsString(json.encode({
  //   //       'is_login':true,
  //   //       'user':user.toJson(),
  //   //       'token':token,
  //   //       'language':language
  //   //     }));
  //   //     return true;
  //   // }else{
  //       //await _prefs.setString('user', json.encode(user.toJson()));
  //       await _prefs.setBool('is_login', true);
  //       await _prefs.setString('token', token);
  //       await _prefs.setInt('language', language.index);
  //       await Future.delayed(Duration(milliseconds: 250));
  //       return true;
  //   // }
  // }

  static Future<bool> resetConfig() async {
    if (_prefs == null) return false;
    // token = null;
    // await _prefs.remove('is_login');
    // await _prefs.remove('user');
    // await _prefs.remove('token');
    await _prefs?.clear();
    return true;
  }

  // static Future<bool> loadConfig()async{
  //   if(isLogin) return true;
  //   try{
  //   // if(_useFile){
  //   //   var file = File("${DatabaseService.pathString}config.json");
  //   //   var dataString = await file.readAsString();
  //   //   var  data= json.decode(dataString);
  //   //   print('-------- Config Loaded $data');
  //   //   isLogin = data['is_login'] ?? false;
  //   //   user = User.fromJson(data['user']);
  //   //   token = data['token'];
  //   //   language = Language.values[data['language'] ?? 0];
  //   //   print('isLogin $isLogin, token $token, user ${user?.fullName}');
  //   // }else{
  //     isLogin = _prefs.getBool('is_login') ?? false;
  //     //user = User.fromJson(json.decode(_prefs.getString('user')));
  //     token = _prefs.getString('token');
  //     language = Language.values[_prefs.getInt('language') ?? 0];

  //   // }
  //   return true;
  //   }catch(err){
  //     print("XXXXX loadConfig Error: _useFile=$_useFile : $err");
  //     language =Language.arabic;
  //     return true;
  //   }
  // }

  static Future<bool> setValueMap(dynamic key, Map v) async {
    if (_prefs == null) return false;
    await _prefs?.setString(
        key.toString(), json.encode(v, toEncodable: ApiService.customEncode));
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static Future<bool> setValueString(dynamic key, String? v) async {
    if (_prefs == null) return false;
    if (v == null)
      _prefs?.remove(key.toString());
    else
      await _prefs?.setString(key.toString(), v);
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static Future<bool> setValueBool(dynamic key, bool v) async {
    if (_prefs == null) return false;
    await _prefs?.setBool(key.toString(), v);
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static Future<bool> setValueInt(dynamic key, int v) async {
    if (_prefs == null) return false;
    await _prefs?.setInt(key.toString(), v);
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static String getValueString(dynamic key) {
    if (_prefs == null) return '';
    return _prefs?.getString(key.toString()) ?? '';
  }

  static Map getValueMap(dynamic key) {
    return json.decode(_prefs?.getString(key.toString()) ?? '{}') ?? {};
  }

  static int getValueInt(dynamic key) {
    return _prefs?.getInt(key.toString()) ?? 0;
  }

  static bool getValueBool(dynamic key) {
    return _prefs?.getBool(key.toString()) ?? false;
  }
}
// enum Language{
//     arabic,
//     english
//   }

==> tecfy_basic_package-1.0.2.tar.gz: lib/services/config.service.dart <==
part of tecfy_basic_package;

class ConfigService {
  static String? apiURL;
  static String? wsURL;
  static bool isRTL = false;

  // static IConfig config;
  static IThemeConfig? theme;
  //static User user;
  // static String token;
  // static Language language = Language.arabic;
  // static bool isArabic = (language ?? Language.arabic) == Language.arabic;
  // static String languagePrefex = (language ?? Language.arabic) == Language.arabic ? 'Ar' : 'En';
  // static bool isLogin = false;
  static SharedPreferences? _prefs;

  static set token(v) {
    if (_prefs == null)
      init().then((_) => setValueString('token', v));
    else
      setValueString('token', v);
  }

  static set isLogin(v) {
    if (_prefs == null)
      init().then((_) => setValueBool('is_login', v));
    else
      setValueBool('is_login', v);
  }

  static bool get isLogin => getValueBool('is_login');
  static String get token => getValueString('token');

  static Future init() async {
    try {
      //if(Platform.isAndroid || Platform.isIOS )
      WidgetsFlutterBinding.ensureInitialized();
      if (_prefs != null) return;
      if (TecfyBasicApp.isTest)
        SharedPreferences.setMockInitialValues({'operation_mode': 1});
      print('----- start prefs');
      _prefs = await SharedPreferences.getInstance();
      print('----- prefs as added');
    } catch (err, t) {
      print('XXXXXXXXXXXXXXXXXXX Config init error XXXXXXXXXXXXXX');
      print(err);
      print(t);
    }
    print('------------Config Done!');
  }

  // static Future<bool> saveConfig()async{
  //   // if(_useFile){
  //   //     // print('--------------- write local collection ($entity)------------------');
  //   //     var file = File("${DatabaseService.pathString}config.json");
  //   //     await file.writeAsString(json.encode({
  //   //       'is_login':true,
  //   //       'user':user.toJson(),
  //   //       'token':token,
  //   //       'language':language
  //   //     }));
  //   //     return true;
  //   // }else{
  //       //await _prefs.setString('user', json.encode(user.toJson()));
  //       await _prefs.setBool('is_login', true);
  //       await _prefs.setString('token', token);
  //       await _prefs.setInt('language', language.index);
  //       await Future.delayed(Duration(milliseconds: 250));
  //       return true;
  //   // }
  // }

  static Future<bool> resetConfig() async {
    if (_prefs == null) return false;
    // token = null;
    // await _prefs.remove('is_login');
    // await _prefs.remove('user');
    // await _prefs.remove('token');
    await _prefs?.clear();
    return true;
  }

  // static Future<bool> loadConfig()async{
  //   if(isLogin) return true;
  //   try{
  //   // if(_useFile){
  //   //   var file = File("${DatabaseService.pathString}config.json");
  //   //   var dataString = await file.readAsString();
  //   //   var  data= json.decode(dataString);
  //   //   print('-------- Config Loaded $data');
  //   //   isLogin = data['is_login'] ?? false;
  //   //   user = User.fromJson(data['user']);
  //   //   token = data['token'];
  //   //   language = Language.values[data['language'] ?? 0];
  //   //   print('isLogin $isLogin, token $token, user ${user?.fullName}');
  //   // }else{
  //     isLogin = _prefs.getBool('is_login') ?? false;
  //     //user = User.fromJson(json.decode(_prefs.getString('user')));
  //     token = _prefs.getString('token');
  //     language = Language.values[_prefs.getInt('language') ?? 0];

  //   // }
  //   return true;
  //   }catch(err){
  //     print("XXXXX loadConfig Error: _useFile=$_useFile : $err");
  //     language =Language.arabic;
  //     return true;
  //   }
  // }

  static Future<bool> setValueMap(dynamic key, Map v) async {
    if (_prefs == null) return false;
    await _prefs?.setString(
        key.toString(), json.encode(v, toEncodable: ApiService.customEncode));
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static Future<bool> setValueString(dynamic key, String? v) async {
    if (_prefs == null) return false;
    if (v == null)
      _prefs?.remove(key.toString());
    else
      await _prefs?.setString(key.toString(), v);
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static Future<bool> setValueBool(dynamic key, bool v) async {
    if (_prefs == null) return false;
    await _prefs?.setBool(key.toString(), v);
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static Future<bool> setValueInt(dynamic key, int v) async {
    if (_prefs == null) return false;
    await _prefs?.setInt(key.toString(), v);
    await Future.delayed(Duration(milliseconds: 250));
    return true;
  }

  static String getValueString(dynamic key) {
    if (_prefs == null) return '';
    return _prefs?.getString(key.toString()) ?? '';
  }

  static Map<String, dynamic> getValueMap(dynamic key) {
    return json.decode(_prefs?.getString(key.toString()) ?? '{}') ?? {};
  }

  static int getValueInt(dynamic key) {
    return _prefs?.getInt(key.toString()) ?? 0;
  }

  static bool getValueBool(dynamic key) {
    return _prefs?.getBool(key.toString()) ?? false;
  }
}
// enum Language{
//     arabic,
//     english
//   }
